@@ -144,7 +144,6 @@ class TerraformModuleDescriptor:
                  exclude_from_tagging: List[str], inputs: List[TerraformModuleInput],
                  outputs: List[TerraformModuleOutput], compute_services: List[TerraformModuleComputeService],
                  module_root_path: str = None, description: str = None, allowed_spaces: List[str] = None):
-
         self.name = module_name
         self.module_repo_name = module_repo_name
         self.module_root_path = module_root_path
@@ -184,6 +183,21 @@ class TerraformModuleDescriptor:
                outputs and inputs
 
 
+class SpaceHelmChartComputeService:
+    def __init__(self, cloud_account_name: str, compute_service_name: str, service_account_name: Optional[str] = None):
+        self.cloud_account_name = cloud_account_name
+        self.compute_service_name = compute_service_name
+        self.service_account_name = service_account_name
+
+    def __eq__(self, other):
+        if not isinstance(other, TerraformModuleComputeService):
+            return NotImplemented
+
+        return self.cloud_account_name.lower() == other.cloud_account_name.lower() and \
+               self.compute_service_name.lower() == other.compute_service_name.lower() and \
+               self.service_account_name.lower() == other.service_account_name.lower()
+
+
 class SpaceTerraformModuleInput:
     def __init__(self, name: str, value: Optional[str], overridable: bool) -> None:
         self.name = name
@@ -195,3 +209,68 @@ class SpaceTerraformModuleInput:
         :return: SpaceTerraformModuleInput
         """
         return SpaceTerraformModuleInput(name=self.name, value=self.value, overridable=self.overridable)
+
+
+class SpaceHelmChartInput:
+    def __init__(self, name: str, path: str, value: Optional[str], description: Optional[str],
+                 overridable: bool, optional: bool, display_style: str) -> None:
+        self.name = name
+        self.path = path
+        self.value = value
+        self.description = description
+        self.overridable = overridable
+        self.optional = optional
+        self.display_style = display_style
+
+    def clone(self):
+        return SpaceHelmChartInput(name=self.name, path=self.path, value=self.value, description=self.description,
+                                   overridable=self.overridable, optional=self.optional,
+                                   display_style=self.display_style)
+
+
+class SpaceHelmChartOutput:
+    def __init__(self, name: str, description: Optional[str], display_style: str, value: str) -> None:
+        self.name = name
+        self.description = description
+        self.display_style = display_style
+        self.value = value
+
+    def clone(self):
+        return SpaceHelmChartOutput(name=self.name, description=self.description,
+                                    display_style=self.display_style, value=self.value)
+
+
+class HelmChartDescriptor:
+    def __init__(self, name: str, perform_helm_test: bool, enable_logs: bool, inputs: List[SpaceHelmChartInput],
+                 outputs: List[SpaceHelmChartOutput], compute_service: SpaceHelmChartComputeService,
+                 chart_root_path: Optional[str] = None, description: Optional[str] = None,
+                 override_values_yaml: Optional[str] = None, commands: Optional[List[str]] = None):
+        self.name = name
+        self.chart_root_path = chart_root_path
+        self.description = description
+        self.enable_logs = enable_logs
+        self.perform_helm_test = perform_helm_test
+        self.override_values_yaml = override_values_yaml
+        self.compute_service = compute_service
+        self.outputs = outputs
+        self.inputs = inputs
+        self.commands = commands
+
+    def __eq__(self, other):
+        if not isinstance(other, HelmChartDescriptor):
+            return NotImplemented
+
+        name = self.name == other.name
+        chart_root_path = self.chart_root_path == other.chart_root_path
+        description = self.description == other.description
+        enable_logs = self.enable_logs == other.enable_logs
+        perform_helm_test = self.perform_helm_test == other.perform_helm_test
+        override_values_yaml = self.override_values_yaml == other.override_values_yaml
+        compute_service = self.compute_service == other.compute_service
+        outputs = AssertionHelper.compare_arrays(self.outputs, other.outputs)
+        inputs = AssertionHelper.compare_arrays(self.inputs, other.inputs)
+        commands = AssertionHelper.compare_arrays(self.commands, other.commands)
+
+        return name and chart_root_path and description and enable_logs and perform_helm_test and compute_service and \
+            compute_service and compute_service and override_values_yaml and \
+            outputs and inputs and commands
