@@ -1,8 +1,12 @@
 from typing import List, Optional
 from datetime import datetime
 import dateutil.parser
+import isodate
+
+from common.test_utils import ServiceType
 from gateways.common.cs18_api_classes import AccessLink, TerraformModuleDescriptor, TerraformModuleComputeService, \
-    TerraformModuleInput, TerraformModuleOutput, SpaceTerraformModuleInput
+    TerraformModuleInput, TerraformModuleOutput, SpaceTerraformModuleInput, SpaceHelmChartInput, SpaceHelmChartOutput, \
+    SpaceHelmChartComputeService
 from gateways.common.cs18_api_errors import SandboxError, Error
 from gateways.common.cs18_api_requests import AwsCloudProviderSettingsModel
 from gateways.common.cs18_api_responses import (GetSpacesResponse, CreateAccountFinalizeResponse, ParameterStoreItem,
@@ -45,7 +49,9 @@ from gateways.common.cs18_api_responses import (GetSpacesResponse, CreateAccount
                                                 TerraformModuleDescriptorResponse, CustomTagResponse,
                                                 CustomTagOverrideResponse, ServiceTfLogsResponse,
                                                 ServiceTfLogInfo, SpaceTerraformModuleResponse, BlueprintTagResponse,
-                                                AccountRepositoryItemResponse, CustomTagWithStatisticsResponse)
+                                                AccountRepositoryItemResponse, SpaceHelmChartModuleResponse,
+                                                TerraformServiceResponse, HelmServiceResponse,
+                                                CustomTagWithStatisticsResponse, BlueprintPolicyResponse)
 
 
 class Converters:
@@ -992,13 +998,24 @@ class Converters:
 
     @staticmethod
     def _create_service_response(service: dict) -> ServiceResponse:
-        return ServiceResponse(
-            name=service["name"],
-            status=service["status"],
-            service_type=service["type"],
-            progress=Converters._create_progress_response(service["progress"]),
-            logs=Converters._create_tf_logs_response(service["logs"])
-        )
+        if service["type"] == ServiceType.TerraForm:
+            return TerraformServiceResponse(
+                name=service["name"],
+                status=service["status"],
+                service_type=service["type"],
+                progress=Converters._create_tf_progress_response(service["progress"]),
+                logs=Converters._create_tf_logs_response(service["logs"])
+            )
+        elif service["type"] == ServiceType.Helm:
+            return HelmServiceResponse(
+                name=service["name"],
+                status=service["status"],
+                service_type=service["type"],
+                progress=service["progress"],
+                logs=service["logs"]
+            )
+        else:
+            raise Exception("Unsupported service type")
 
     @staticmethod
     def _create_tf_logs_response(logs_dict: dict) -> Optional[ServiceTfLogsResponse]:
@@ -1052,7 +1069,7 @@ class Converters:
                                      tf_destroy=tf_destroy)
 
     @staticmethod
-    def _create_progress_response(progress_dict: dict) -> Optional[ServiceTfProgressResponse]:
+    def _create_tf_progress_response(progress_dict: dict) -> Optional[ServiceTfProgressResponse]:
         if progress_dict is None:
             return None
 
@@ -1359,3 +1376,60 @@ class Converters:
             value=input_item["value"],
             overridable=input_item["overridable"]
         )
+
+    @staticmethod
+    def create_blueprint_policy_response(data: dict) -> BlueprintPolicyResponse:
+        return BlueprintPolicyResponse(
+            max_duration=isodate.parse_duration(data['max_duration']) if data['max_duration'] else None
+        )
+
+    @staticmethod
+    def create_space_helm_chart_response(data: dict) -> SpaceHelmChartModuleResponse:
+        return SpaceHelmChartModuleResponse(
+            name=data["name"],
+            perform_helm_test=data["perform_helm_test"],
+            enable_logs=data["enable_logs"],
+            inputs=[Converters.convert_space_helm_chart_input(input_item) for input_item
+                    in data["inputs"]],
+            outputs=[Converters.convert_space_helm_chart_output(output_item) for output_item
+                     in data["outputs"]],
+            commands=data["commands"],
+            compute_service=Converters.convert_space_helm_chart_compute_service(
+                data["compute_service"]),
+            chart_root_path=data["chart_root_path"],
+            override_values_yaml=data["override_values_yaml"],
+            description=data["description"],
+            created_by=data["created_by"],
+            created_date=data["created_date"],
+            modified_by=data["modified_by"],
+            last_modified=data["last_modified"]
+        )
+
+    @staticmethod
+    def convert_space_helm_chart_compute_service(compute_service: dict) -> SpaceHelmChartComputeService:
+        return SpaceHelmChartComputeService(
+            cloud_account_name=compute_service["cloud_account_name"],
+            compute_service_name=compute_service["compute_service_name"],
+            service_account_name=compute_service["service_account_name"]
+        )
+
+    @staticmethod
+    def convert_space_helm_chart_input(input_item: dict) -> SpaceHelmChartInput:
+        return SpaceHelmChartInput(
+            name=input_item["name"],
+            path=input_item["path"],
+            value=input_item["value"],
+            description=input_item["description"],
+            optional=input_item["optional"],
+            overridable=input_item["overridable"],
+            display_style=input_item["display_style"]
+        )
+
+    @staticmethod
+    def convert_space_helm_chart_output(output_item: dict) -> SpaceHelmChartOutput:
+        return SpaceHelmChartOutput(
+            name=output_item["name"],
+            description=output_item["description"],
+            display_style=output_item["display_style"],
+            value=output_item["value"]
+        )
