@@ -6,6 +6,9 @@ from enum import Enum
 from typing import List, Optional
 
 from gateways.common.cs18_api_classes import SpaceTerraformModuleInput
+from gateways.common.cs18_api_classes import SpaceHelmChartComputeService
+from gateways.common.cs18_api_classes import SpaceHelmChartInput
+from gateways.common.cs18_api_classes import SpaceHelmChartOutput
 
 
 class ProductionEnvironment(Enum):
@@ -214,3 +217,55 @@ class UpdateSpaceTerraformModuleRequest(SpaceTerraformModuleRequestBase):
             enable_logs=enable_logs,
             inputs=inputs
         )
+
+
+class AddSpaceHelmChartRequest(metaclass=ABCMeta):
+    def __init__(
+            self,
+            name: str,
+            chart_root_path: str,
+            compute_service: SpaceHelmChartComputeService,
+            perform_helm_test: bool,
+            enable_logs: bool,
+            inputs: List[SpaceHelmChartInput],
+            outputs: List[SpaceHelmChartOutput],
+            description: Optional[str] = None,
+            commands: Optional[List[str]] = None,
+            override_values_yaml: Optional[str] = None,
+    ):
+        self.name = name
+        self.description = description
+        self.compute_service = compute_service
+        self.perform_helm_test = perform_helm_test
+        self.chart_root_path = chart_root_path
+        self.enable_logs = enable_logs
+        self.override_values_yaml = override_values_yaml
+        self.inputs = inputs
+        self.outputs = outputs
+        self.commands = commands
+
+
+class UpdateSpaceHelmChartRequest(metaclass=ABCMeta):
+    def __init__(
+            self,
+            name: str,
+            chart_root_path: str,
+            compute_service: SpaceHelmChartComputeService,
+            perform_helm_test: bool,
+            enable_logs: bool,
+            inputs: List[SpaceHelmChartInput],
+            outputs: List[SpaceHelmChartOutput],
+            description: Optional[str] = None,
+            commands: Optional[List[str]] = None,
+            override_values_yaml: Optional[str] = None,
+    ):
+        self.name = name
+        self.description = description
+        self.compute_service = compute_service
+        self.perform_helm_test = perform_helm_test
+        self.chart_root_path = chart_root_path
+        self.enable_logs = enable_logs
+        self.override_values_yaml = override_values_yaml
+        self.inputs = inputs
+        self.outputs = outputs
+        self.commands = commands
