@@ -32,7 +32,7 @@ class ServiceStatus:
     VALIDATION_FAILED = "ValidationFailed"
 
 
-class TfStageStatus:
+class ServiceStageStatus:
     PENDING = "Pending"
     EXECUTING = "Executing"
     DONE = "Done"
